/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
import { IDocumentManager, IDocument, ITenantManager, IDocumentStaticProperties, ICache } from "@fluidframework/server-services-core";
/**
 * Manager to fetch document from Alfred using the internal URL.
 */
export declare class DocumentManager implements IDocumentManager {
    private readonly internalAlfredUrl;
    private readonly tenantManager;
    private readonly documentStaticDataCache?;
    constructor(internalAlfredUrl: string, tenantManager: ITenantManager, documentStaticDataCache?: ICache);
    readDocument(tenantId: string, documentId: string): Promise<IDocument>;
    readStaticProperties(tenantId: string, documentId: string): Promise<IDocumentStaticProperties | undefined>;
    purgeStaticCache(documentId: string): Promise<void>;
    private getBasicRestWrapper;
    /**
     * Creates a cache key to retreive static data from a document
     *
     * @param documentId - ID of the document to create an access key for
     * @returns - A cache key to access static data for [documentId]
     */
    private static getDocumentStaticKey;
    /**
     * Extracts the static properties from an IDocument
     *
     * @param document - Document to get properties from
     * @returns - The static properties of [document]
     */
    private static getStaticPropsFromDoc;
}
//# sourceMappingURL=documentManager.d.ts.map