"use strict";
/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.TenantManager = exports.Tenant = void 0;
const server_services_client_1 = require("@fluidframework/server-services-client");
const server_services_utils_1 = require("@fluidframework/server-services-utils");
const core = __importStar(require("@fluidframework/server-services-core"));
const common_utils_1 = require("@fluidframework/common-utils");
const server_services_telemetry_1 = require("@fluidframework/server-services-telemetry");
const _1 = require(".");
class Tenant {
    constructor(config, manager) {
        this.config = config;
        this.manager = manager;
    }
    get id() {
        return this.config.id;
    }
    get gitManager() {
        return this.manager;
    }
    get storage() {
        return this.config.storage;
    }
    get orderer() {
        return this.config.orderer;
    }
}
exports.Tenant = Tenant;
/**
 * Manages a collection of tenants
 */
class TenantManager {
    constructor(endpoint, internalHistorianUrl) {
        this.endpoint = endpoint;
        this.internalHistorianUrl = internalHistorianUrl;
    }
    async createTenant(tenantId) {
        const restWrapper = new server_services_client_1.BasicRestWrapper(undefined /* baseUrl */, undefined /* defaultQueryString */, undefined /* maxBodyLength */, undefined /* maxContentLength */, undefined /* defaultHeaders */, undefined /* axios */, undefined /* refreshDefaultQureyString */, undefined /* refreshDefaultHeaders */, server_services_utils_1.getCorrelationId);
        const result = await restWrapper.post(`${this.endpoint}/api/tenants/${encodeURIComponent(tenantId || "")}`, undefined);
        return result;
    }
    async getTenant(tenantId, documentId, includeDisabledTenant = false) {
        const [details, gitManager] = await Promise.all([
            this.getTenantConfig(tenantId, includeDisabledTenant),
            this.getTenantGitManager(tenantId, documentId, undefined, includeDisabledTenant),
        ]);
        const tenant = new Tenant(details, gitManager);
        return tenant;
    }
    async getTenantGitManager(tenantId, documentId, storageName, includeDisabledTenant = false, isEphemeralContainer = false) {
        const lumberProperties = {
            ...(0, server_services_telemetry_1.getLumberBaseProperties)(documentId, tenantId),
            [server_services_telemetry_1.CommonProperties.isEphemeralContainer]: isEphemeralContainer,
        };
        const key = await core.requestWithRetry(async () => this.getKey(tenantId, includeDisabledTenant), "getTenantGitManager_getKey" /* callName */, lumberProperties /* telemetryProperties */);
        const defaultQueryString = {
            token: (0, common_utils_1.fromUtf8ToBase64)(`${tenantId}`),
        };
        const getDefaultHeaders = () => {
            const credentials = {
                password: (0, server_services_utils_1.generateToken)(tenantId, documentId, key, null),
                user: tenantId,
            };
            const headers = {
                Authorization: (0, server_services_client_1.getAuthorizationTokenFromCredentials)(credentials),
            };
            if (storageName) {
                headers.StorageName = storageName;
            }
            // IsEphemeralContainer header is set only for ephemeral containers
            // It is not set if it is not ephemeral and when the driver did not send any info
            if (isEphemeralContainer) {
                headers[_1.IsEphemeralContainer] = isEphemeralContainer;
            }
            return headers;
        };
        const defaultHeaders = getDefaultHeaders();
        const baseUrl = `${this.internalHistorianUrl}/repos/${encodeURIComponent(tenantId)}`;
        const tenantRestWrapper = new server_services_client_1.BasicRestWrapper(baseUrl, defaultQueryString, undefined, undefined, defaultHeaders, undefined, undefined, getDefaultHeaders, server_services_utils_1.getCorrelationId);
        const historian = new server_services_client_1.Historian(`${this.internalHistorianUrl}/repos/${encodeURIComponent(tenantId)}`, true, false, tenantRestWrapper);
        const gitManager = new server_services_client_1.GitManager(historian);
        return gitManager;
    }
    async verifyToken(tenantId, token) {
        const restWrapper = new server_services_client_1.BasicRestWrapper(undefined /* baseUrl */, undefined /* defaultQueryString */, undefined /* maxBodyLength */, undefined /* maxContentLength */, undefined /* defaultHeaders */, undefined /* axios */, undefined /* refreshDefaultQureyString */, undefined /* refreshDefaultHeaders */, server_services_utils_1.getCorrelationId);
        await restWrapper.post(`${this.endpoint}/api/tenants/${encodeURIComponent(tenantId)}/validate`, { token });
    }
    async getKey(tenantId, includeDisabledTenant = false) {
        const restWrapper = new server_services_client_1.BasicRestWrapper(undefined /* baseUrl */, undefined /* defaultQueryString */, undefined /* maxBodyLength */, undefined /* maxContentLength */, undefined /* defaultHeaders */, undefined /* axios */, undefined /* refreshDefaultQureyString */, undefined /* refreshDefaultHeaders */, server_services_utils_1.getCorrelationId);
        const result = await restWrapper.get(`${this.endpoint}/api/tenants/${encodeURIComponent(tenantId)}/keys`, { includeDisabledTenant });
        return result.key1;
    }
    async getTenantStorageName(tenantId, includeDisabledTenant = false) {
        const tenantConfig = await this.getTenantConfig(tenantId, includeDisabledTenant);
        return tenantConfig?.customData?.storageName;
    }
    async getTenantConfig(tenantId, includeDisabledTenant = false) {
        const restWrapper = new server_services_client_1.BasicRestWrapper(undefined /* baseUrl */, undefined /* defaultQueryString */, undefined /* maxBodyLength */, undefined /* maxContentLength */, undefined /* defaultHeaders */, undefined /* axios */, undefined /* refreshDefaultQureyString */, undefined /* refreshDefaultHeaders */, server_services_utils_1.getCorrelationId);
        return restWrapper.get(`${this.endpoint}/api/tenants/${tenantId}`, {
            includeDisabledTenant,
        });
    }
}
exports.TenantManager = TenantManager;
//# sourceMappingURL=tenant.js.map